@@ -12,7 +12,7 @@ class IODict(dict):
         """
         # if first argument is data-string, url or filepath try to decode it.
         # use 'format' kwarg to specify the decoder to use, default 'json'.
-        if len(args) and type_util.is_string(args[0]):
+        if len(args) == 1 and type_util.is_string(args[0]):
             d = IODict._decode_init(args[0], **kwargs)
             super(IODict, self).__init__(d)
             return
@@ -20,16 +20,13 @@ class IODict(dict):
 
     @staticmethod
     def _decode_init(s, **kwargs):
-        default_format = io_util.autodetect_format(s, default='json')
+        autodetected_format = io_util.autodetect_format(s)
+        default_format = autodetected_format or 'json'
         format = kwargs.pop('format', default_format).lower()
         if format in ['b64', 'base64']:
             kwargs.setdefault('subformat', 'json')
         # decode data-string and initialize with dict data.
-        try:
-            d = IODict._decode(s, format, **kwargs)
-            return d
-        except ValueError:
-            raise ValueError('Invalid string data input.')
+        return IODict._decode(s, format, **kwargs)
 
     @staticmethod
     def _decode(s, format, **kwargs):
@@ -83,6 +80,16 @@ class IODict(dict):
         kwargs['columns_row'] = columns_row
         return cls(s, format='csv', **kwargs)
 
+    @classmethod
+    def from_json(cls, s, **kwargs):
+        """
+        Load and decode JSON data from url, filepath or data-string.
+        Decoder specific options can be passed using kwargs:
+        https://docs.python.org/3/library/json.html
+        Return a new dict instance. A ValueError is raised in case of failure.
+        """
+        return cls(s, format='json', **kwargs)
+
     @classmethod
     def from_pickle(cls, s, **kwargs):
         """
@@ -94,14 +101,14 @@ class IODict(dict):
         return cls(s, format='pickle', **kwargs)
 
     @classmethod
-    def from_json(cls, s, **kwargs):
+    def from_plist(cls, s, **kwargs):
         """
-        Load and decode JSON data from url, filepath or data-string.
+        Load and decode p-list data from url, filepath or data-string.
         Decoder specific options can be passed using kwargs:
-        https://docs.python.org/3/library/json.html
+        https://docs.python.org/3/library/plistlib.html
         Return a new dict instance. A ValueError is raised in case of failure.
         """
-        return cls(s, format='json', **kwargs)
+        return cls(s, format='plist', **kwargs)
 
     @classmethod
     def from_query_string(cls, s, **kwargs):
@@ -165,6 +172,16 @@ class IODict(dict):
         kwargs['columns_row'] = columns_row
         return self._encode(self[key], 'csv', **kwargs)
 
+    def to_json(self, **kwargs):
+        """
+        Encode the current dict instance in JSON format.
+        Encoder specific options can be passed using kwargs:
+        https://docs.python.org/3/library/json.html
+        Return the encoded string and optionally save it at 'filepath'.
+        A ValueError is raised in case of failure.
+        """
+        return self._encode(self, 'json', **kwargs)
+
     def to_pickle(self, **kwargs):
         """
         Encode the current dict instance as pickle (encoded in Base64).
@@ -176,15 +193,15 @@ class IODict(dict):
         """
         return self._encode(self, 'pickle', **kwargs)
 
-    def to_json(self, **kwargs):
+    def to_plist(self, **kwargs):
         """
-        Encode the current dict instance in JSON format.
+        Encode the current dict instance as p-list.
         Encoder specific options can be passed using kwargs:
-        https://docs.python.org/3/library/json.html
+        https://docs.python.org/3/library/plistlib.html
         Return the encoded string and optionally save it at 'filepath'.
         A ValueError is raised in case of failure.
         """
-        return self._encode(self, 'json', **kwargs)
+        return self._encode(self, 'plist', **kwargs)
 
     def to_query_string(self, **kwargs):
         """
